## $Id: utils.py 16675 2021-10-11 06:24:49Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""General helper functions and utilities for the application section.
"""

from kofacustom.nigeria.applicants.utils import NigeriaApplicantsUtils
from waeup.aaue.interswitch.browser import GATEWAY_AMT
from waeup.aaue.interfaces import MessageFactory as _


class ApplicantsUtils(NigeriaApplicantsUtils):
    """A collection of parameters and methods subject to customization.
    """

    ADDITIONAL_FILES = (('Statement of Result','stateresult'),
                 ('Result/Certificate Document','verificationdoc'))

    APP_TYPES_DICT = {
        'utme': ['AAUE Admission Screening (UTME)', 'UTME'],
        'ude': ['AAUE Admission Screening (UDE)', 'UDE'],
        'fp': ['Foundation Programmes', 'FND'],
        'ptee': ['Part-Time Entrance Examination', 'PTEE'],
        'app': ['General Studies', 'APP'],
        'pgft': ['Postgraduate Full-Time Programmes', 'PG'],
        'pgpt': ['Postgraduate Part-Time Programmes', 'PG'],
        'trans': ['Transcript Application', 'TR'],
        'cert': ['Certificate Request', 'CR'],
        'ioedp': ['Institute of Education Diploma Programmes', 'IOE'],
        'ijmbe': ['Interim Joint Matriculation Board Examination', 'IJMBE'],
        'bridge': ['Bridge Programme', 'BRI'],
        'dsh': ['Science and Humanities Programme', 'DSH'],
        'ver': ['Verification Request', 'VR'],
        'send': ['Send-By-Email Request', 'SE'],
        'fedex': ['Payment for Courier (Fedex)', 'FED'],
        'rec': ['AAU Recruitment', 'REC'],
        }

    SEPARATORS_DICT = {
        'form.applicant_id': _(u'Base Data'),
        #'form.course1': _(u'Programmes/Courses Desired'),
        'form.fst_sit_fname': _(u'1st Sitting'),
        'form.scd_sit_fname': _(u'2nd Sitting'),
        'form.alr_fname': _(u'Advanced Level Record'),
        'form.hq_type': _(u'1st Higher Education Record'),
        'form.hq_type2': _(u'2nd Higher Education Record'),
        'form.hq_type3': _(u'3rd Higher Education Record'),
        'form.presently': _(u'Course or Programme Presently Attending'),
        'form.nysc_year': _(u'NYSC Information'),
        'form.employer': _(u'Employment History'),
        #'form.jamb_reg_number': _(u'JAMB Data'),
        'form.notice': _(u'Application Process Information'),
        'form.pp_school': _(u'Post Primary School Qualification'),
        'form.presently_inst': _(u'Presently attending a course or programme'),
        'form.olevel_type': _(u"'O' Level Records"),
        'form.former_matric': _(u'Former Student'),
        }

    def sortCertificates(self, context, resultset):
        """Sort already filtered certificates in `AppCatCertificateSource`.
        """
        resultlist = sorted(resultset, key=lambda
            value: value.__parent__.__parent__.__parent__.code +
            value.__parent__.__parent__.code +
            value.code)
        curr_course = context.course1
        if curr_course is not None and curr_course not in resultlist:
            resultlist = [curr_course,] + resultlist
        return resultlist

    def getCertTitle(self, context, value):
        """Compose the titles in `AppCatCertificateSource`.
        """
        try: title = "%s / %s / %s (%s)" % (
            value.__parent__.__parent__.__parent__.code,
            value.__parent__.__parent__.code,
            value.title, value.code)
        except AttributeError:
            title = "NA / %s (%s)" % (value.title, value.code)
        return title

    def setPaymentDetails(self, container, payment, applicant):
        msg = super(ApplicantsUtils, self).setPaymentDetails(
            container, payment, applicant)
        if msg:
            return msg
        if applicant.container_code.startswith('trans') or \
            applicant.container_code.startswith('cert'):
            payment.amount_auth = applicant.no_copies * container.application_fee - \
                (applicant.no_copies-1) * GATEWAY_AMT
        return

    def isPictureEditable(self, container):
        """False if applicants are not allowed to edit uploaded pictures.
        """
        # see ticket #656
        #return container.with_picture and \
        #    not container.prefix.startswith('utme') and \
        #    not container.prefix.startswith('ude')
        return True